require_relative 'java_plugins'

class PivotalTrackerPublisher < Jenkins::Tasks::Publisher

  display_name 'Pivotal Tracker Notification'

  attr_reader :tracker_token, :tracker_project_id, :changelog_file

  def initialize(attrs)
    @tracker_token = attrs['tracker_token']
    @tracker_project_id = attrs['tracker_project_id']
    @changelog_file = attrs['changelog_file']
  end

  def perform(build, launcher, listener)
    notifier = PivotalTrackerBuildNotifier.new(build, listener, self)
    begin
      notifier.notify!
      listener.info "Successfully integrated #{TokenMacroJavaPlugin.expand_value(build, listener, job_name)} build info with Pivotal Tracker Project ##{TokenMacroJavaPlugin.expand_value(build, listener, tracker_project_id)}"
    rescue => e
      listener.error ['An error occurred while sending Pivotal Tracker notifications', e.message, e.backtrace] * "\n"
    end
  end

  def job_name
    '${JOB_NAME}'
  end

  def build_url
    '${BUILD_URL}'
  end

end